# Options for ndiswrapper.
#

# Set this alias to some device. Usually wlan0 unless you've got more than one
# wireless card.

#alias wlan0 ndiswrapper

# loadndisdriver requires 4 parameters.
# 
# Uncomment the following line after you've added the paths
# to the .sys and .inf files from Windows(tm)
#
#post-install ndiswrapper loadndisdriver VENDORID DEVICEID foo.sys foo.inf
